Lighthouse has a new layout. Prefer the old one? Return to the old layout, and switch back any time from the link at the top of each page.

This project is archived and is in readonly mode.

Plugin install with fails with --verbose option

#4686

$ script/plugin install --verbose http://github.com/rails/rails_xss.git Plugin not found: ["http://github.com/rails/rails_xss.git"]

Mac
Rails 2.3.8
git version 1.7.0
$ ruby -v ruby 1.8.7 (2010-01-10 patchlevel 249) [i686-darwin10]

Reported by Luiz Aguiar · May 25th, 2010 @ 07:10 AM

State: new
Milestone: none
Assigned to: nobody
Importance: Low

Activity

  1. Anil Wadghule
    Anil Wadghule

    This is an issue with rails 2.3.5 too. Try without --verbose, it should work.

    May 25th, 2010 @ 08:28 AM

  2. Luiz Aguiar
    Luiz Aguiar

    Without --verbose, the install stay "running" for minutes, and don't install the plugin.
    I tried to install others plugins and just work.

    May 25th, 2010 @ 02:13 PM

  3. Santiago Pastorino
    Santiago Pastorino

    script/plugin install git://github.com/rails/rails_xss.git should work.
    --verbose is failing yes, seems like a bug.

    May 25th, 2010 @ 03:53 PM

  4. Jeff Kreeftmeijer
    Jeff Kreeftmeijer
    • Tag changed from plugins, xss to plugins

    Same problem on master:

    $ script/rails plugin install git://github.com/rails/rails_xss.git --verbose
    Plugin not found: []
    

    It doesn't seem to have to do anything with rails_xss, though. I get exactly the same when I try to install Paperclip as a plugin, so --verbose is the problem here.

    Can somebody change the ticket name? "Plugin install with fails with --verbose option" seems like a better fit. :)

    May 26th, 2010 @ 09:35 AM

  5. Łukasz Strzałkowski
    Łukasz Strzałkowski
    • Title changed from rails_xss plugin not found on install to Plugin install with fails with --verbose option
    • Importance changed from to Low

    The problem is with order of params, not with verbose options it self.

    If you invoke:

    
    strzalek@imac-strzalek ~/projects/ruby/rails_sandbox ➔ script/rails plugin --verbose install git://github.com/rails/rails_xss.git
    Plugins will be installed using http
    git init
    Initialized empty Git repository in /Users/strzalek/projects/ruby/rails_sandbox/vendor/plugins/rails_xss/.git/
    git pull --depth 1 git://github.com/rails/rails_xss.git
    remote: Counting objects: 33, done.
    remote: Compressing objects: 100% (32/32), done.
    remote: Total 33 (delta 5), reused 3 (delta 0)
    Unpacking objects: 100% (33/33), done.
    From git://github.com/rails/rails_xss
     * branch            HEAD       -> FETCH_HEAD
    removing: .git .gitignore
    

    It will work without problems. But when I execute command with --verbose at the end, then I'm also encountering errors:

    strzalek@imac-strzalek ~/projects/ruby/rails_sandbox ➔ script/rails plugin install git://github.com/rails/rails_xss.git --verbose
    Plugin not found: []
    

    Actually it's even not an error.

    July 9th, 2010 @ 08:07 PM

  6. chaitanyav
    chaitanyav

    @lukasz as you said , I tried this

    neo@myhost ~/p/awesome> 
    rails plugin --verbose install  git://github.com/rails/rails_xss.git
    "install"
    Plugins will be installed using http
    git init
    Initialized empty Git repository in /home/neo/projects/awesome/vendor/plugins/rails_xss/.git/
    git pull --depth 1 git://github.com/rails/rails_xss.git
    remote: Counting objects: 33, done.
    remote: Compressing objects: 100% (32/32), done.
    remote: Total 33 (delta 5), reused 3 (delta 0)
    Unpacking objects: 100% (33/33), done.
    From git://github.com/rails/rails_xss
     * branch            HEAD       -> FETCH_HEAD
    removing: .git .gitignore
    

    Now, I will remove the plugin

    neo@myhost ~/p/awesome> 
    rails plugin --verbose remove  git://github.com/rails/rails_xss.git
    "remove"
    Removing 'vendor/plugins/rails_xss'
    

    I hacked the rails gem to find out what is actually happening in the code. I changed this file railties-3.0.0.beta4/lib/rails/commands/plugin.rb

    BTW, I added "p e.message" after line 422.

    I will add the --verbose at the end

    rails plugin  install git://github.com/rails/rails_xss.git --verbose
    "invalid option: --verbose"
    Plugin not found: []
    
    one more try
    neo@myhost ~/p/awesome> 
    rails plugin  install git://github.com/rails/rails_xss.git --quiet
    

    According to the code --verbose at the end is a invalid option

    The command can be used in the following ways

    neo@myhost ~/p/awesome> rails plugin
    Unknown command: 
    Usage: plugin [OPTIONS] command
    Rails plugin manager.
    GENERAL OPTIONS
      -r, --root=DIR                   Set an explicit rails app directory. Default: /home/neo/projects/awesome
      -s, --source=URL1,URL2           Use the specified plugin repositories instead of the defaults.
      -v, --verbose                    Turn on verbose output.
      -h, --help                       Show this help message.
    COMMANDS
      install    Install plugin(s) from known repositories or URLs.
      remove     Uninstall plugins.
    EXAMPLES
      Install a plugin:
      rails plugin install continuous_builder
      Install a plugin from a subversion URL:
      rails plugin install http://dev.rubyonrails.com/svn/rails/plugins/continuous_builder
      Install a plugin from a git URL:
      rails plugin install git://github.com/SomeGuy/my_awesome_plugin.git
      Install a plugin and add a svn:externals entry to vendor/plugins
      rails plugin install -x continuous_builder
    

    OR

    neo@myhost ~/p/awesome> 
    rails plugin  install git://github.com/rails/rails_xss.git --help
    Usage: rails install PLUGIN [PLUGIN [PLUGIN] ...]
    Install one or more plugins.
    Options:
      -x, --externals                  Use svn:externals to grab the plugin.Enables plugin updates and plugin versioning.
      -o, --checkout                   Use svn checkout to grab the plugin.Enables updating but does not add a svn:externals entry.
      -e, --export                     Use svn export to grab the plugin.Exports the plugin, allowing you to check it into your local repository. Does not enable updates, or add an svn:externals entry.
      -q, --quiet                      Suppresses the output from installation.Ignored if -v is passed (rails plugin -v install ...)
      -r, --revision REVISION          Checks out the given revision from subversion or git.Ignored if subversion/git is not used.
      -f, --force                      Reinstalls a plugin if it's already installed.
    
    You can specify plugin names as given in 'plugin list' output or absolute URLs to 
    a plugin repository.
    

    please verify this

    July 10th, 2010 @ 06:19 AM

  7. af001
    af001

    私の中で、総合評価のとっても低いアバアバクロホリスタークロ銀座店。アバクロは大好きなんですけどね。一昨日の東京駅付近での打ち合わせの後、散歩がてら久々に行ってきました。そしたらビックリ!相変わらアバクロず、踊っているだけの店員さんとかもいましたが、

    May 5th, 2011 @ 02:54 AM